@@ -25,10 +25,16 @@ DEFAULT_BUNDLE_PATH = os.path.join(os.path.expanduser('~'), ".rqalpha-plus")
 
 PRODUCTS = ["rqalpha_plus", "rqdatac", "rqfactor", "rqoptimizer"]
 CONCERNED_PACKAGES = [
-    "rqsdk", "rqdatac", "rqdatac_fund",
-    "rqfactor", "rqoptimizer", "rqrisk",
-    "rqalpha_plus", "rqalpha", "rqalpha_mod_spot", "rqalpha_mod_option", "rqalpha_mod_optimizer2",
-    "rqalpha_mod_convertible", "rqalpha_mod_ricequant_data", "rqalpha_mod_rqfactor", "rqalpha_mod_fund",
-    "rqalpha_mod_spot",
-    "pandas", "numpy", "h5py"
+    "rqsdk",
+
+    "rqdatac", "wcwidth", "tabulate", 'requests', "cryptography", "click", "jwt", "patsy", "statsmodels",
+    "scipy", "numpy", "pandas", "rapidjson", "rqdatac_fund",
+    
+    "rqfactor", "talib",
+
+    "rqoptimizer", "ecos", "scs", "cvxpy", "osqp", "rqoptimizer2",
+    
+    "rqalpha_plus", "rqalpha", "rqalpha_mod_option", "rqalpha_mod_optimizer2", "rqalpha_mod_convertible",
+    "rqalpha_mod_ricequant_data", "rqalpha_mod_rqfactor", "rqalpha_mod_spot",  "rqalpha_mod_fund",
+    "rqalpha_mod_incremental", "rqrisk", "h5py", "hdf5plugin"
 ]
